@@ -35,7 +35,8 @@ Type some short-hand, see the corresponding SQL and its output:
  select count(*), year(now()), concat_ws(',',1,2,3);
  ...
  steno> .col1,.clm2,.sn;#TBL1:jTBL2 u(id);mydate :b :m+3d and :d-w    -- :jTABLEABBREV and :+/- family
- select column1,column2,somecolumn from TABLE1 join TABLE2 using(id) where mydate between date_format(now(),"%Y-%m-01")+interval 3 day and curdate()-interval 1 week;
+ select column1,column2,somecolumn from TABLE1 join TABLE2 using(id) where mydate
+ between date_format(now(),"%Y-%m-01")+interval 3 day and curdate()-interval 1 week;
  ...
 
 =head1 DESCRIPTION
@@ -64,7 +65,7 @@ with other DBs.
 
 use v5.12;
 
-package SQL::Steno v0.2.2.1;
+package SQL::Steno v0.2.3;
 
 use strict;
 use Time::HiRes qw(gettimeofday tv_interval);
@@ -102,21 +103,34 @@ sub init_from_query {
     push @{$Table_Columns{$table}}, $column while $sth->fetch;
     undef $table_re;		# (re)create below
 }
-my @keys_Table_Columns;
+
+
 
 my %render =
     (csv => \&render_csv,
+     table => \&render_table,
      yaml => \&render_yaml,
      yml => \&render_yaml);
-my $render;
+my( $render, %opt );
 
-our( %Queries_help, %Queries );
-{
-    my $setter = sub { $render = $render{substr $_[0], 1}; "" };
-    for my $fmt ( keys %render ) {
-	$Queries_help{".$fmt"} = "   output '&.$fmt() this' or next query as \U$fmt";
-	$Queries{".$fmt"} = $setter;
+sub set_render($@) {
+    ($render, %opt) = ();
+    for( @_ ) {
+	if( defined $render ) {	# all further args are opts
+	    tr/ \t//d;
+	    undef $opt{$_};	# make it exist
+	} else {
+	    $render = substr $_, 1;
+	}
     }
+    $render = $render{$render};
+    '';				# For use as a query
+}
+our( %Queries_help, %Queries );
+
+for my $fmt ( keys %render ) {
+    $Queries_help{".$fmt"} = "   output '&.$fmt() this' or next query as \U$fmt";
+    $Queries{".$fmt"} = \&set_render;
 }
 sub Queries(@) {
     for( @_ ) {
@@ -353,6 +367,7 @@ sub convert_Queries($$) {
     $res;
 }
 
+my @keys_Table_Columns;
 sub convert_table_column {
     # \todo .col. or .col.alias like #tbl#
     @keys_Table_Columns = keys %Table_Columns unless @keys_Table_Columns;
@@ -580,7 +595,7 @@ sub render_csv($;$$) {
     }
 }
 
-sub render_tabular($;$$) {
+sub render_table($;$$) {
     my( $sth, $filter ) = @_;
     my( $null, $crlf, $date ) =
 	exists $_[2]{all} ?
@@ -711,8 +726,8 @@ sub render_yaml($;$$) {
 
 
 my $lasttime = time;
-sub run($;$) {
-    my( $sql, $filter ) = @_;
+sub run($;$\%) {
+    my( $sql, $filter, $opt ) = @_;
     my $t0 = [gettimeofday];
     if( $DBI::err || $t0->[0] - $lasttime > 3600 and !$dbh->ping ) {
 	printf STDOUT "Inactive for %ds, ping failed after %.03fs, your session variables are lost.\n",
@@ -729,9 +744,9 @@ sub run($;$) {
 	    tv_interval( $t0, $t1 ), tv_interval( $t1 ), $DBI::rows;
 	if( $sth->{Active} ) {
 	    if( $render ) {
-		&$render( $sth, $filter );
+		&$render( $sth, $filter, $opt );
 	    } else {
-		render_tabular $sth, $filter;
+		render_table $sth, $filter, $opt;
 	    }
 	}
     }
@@ -776,7 +791,7 @@ Reprocess result as a shell entry (i.e. it may return another C<&>query).
 =item !/regexp/i statement
 
 This will treat the I<statement> normally, but will join each output row for
-matching as though it were the only row in default tabular format.  That is
+matching as though it were the only row in default table format.  That is
 there is no space padding and the character '|' (which must be matched as
 C<\|>) separates columns.  At this stage no value rewriting has occured,
 except NULL is already rendered as C<\@>.
@@ -825,8 +840,8 @@ Run it.
 
 =item >>filename
 
-Redirect or append next statement's output to I<filename>.  If it has a suffix
-C<.csv>, C<.yaml> or C<.yml>, an according format is used.
+Redirect or append next statement's output to I<filename>.  For known
+suffixes and options, see the L<next section|/Output formats>.
 
 =item |System Shell code
 
@@ -834,6 +849,92 @@ Pipe next statement's output through I<System Shell code>.
 
 =back
 
+
+=head2 Output formats
+
+The output format for the next SQL statement that is run, is chosen from the
+suffix of a redirection or a special suffix query.  In both cases
+comma-separated options may be passed:
+
+=over
+
+=item >filename.suffix
+
+=item >filename.suffix( opt, ... )
+
+=item >>filename.suffix
+
+=item >>filename.suffix( opt, ... )
+
+=item &.suffix opt, ...
+
+=item &.suffix( opt, ... ) following text
+
+=back
+
+The known suffixes and their respective options are:
+
+=over
+
+=item C<.csv>
+
+CSV can take one of these options:
+
+=over
+
+=item semi
+
+Use a semicolon as a separator.  This is a common format in environments where
+the comma is the decimal separator.  However if you want that, you must
+provide such formatting yourself.
+
+=item tab
+
+Use tabulators as column separators.  Apart from that you get the full CSV
+formatting, so this is not the primitive F<.tsv> format some tools may have.
+
+=back
+
+
+=item C<.table>
+
+This is the default table format.  But you need to name it, if you want to set
+options.
+
+=over
+
+=item all
+
+This is a shorthand for outputting everything in the long form, equivalent to
+C<( NULL, crlf, date )>.
+
+=item crlf
+
+Do not shorten C<\r\n> to C<\R>.
+
+=item date
+
+Output ISO dates and times fully instead of shortening them.
+
+=item NULL
+
+=item null
+
+Output this keywork instead of the shorter C<\@>.
+
+=back
+
+
+=item C<.yaml>
+
+=item C<.yml>
+
+Format output as YAML.  This format has no options.  Because its every value
+on a new line format can be more readable, there is a shorthand query C<&->
+for it.
+
+=back
+
 =cut
 
 our $prompt = 'steno> ';
@@ -913,8 +1014,8 @@ sub shell() {
 	    goto NEXT;
 	}
 	s/^\s*()//;			# dummy because $1 survives loop iterations :-o
-	if( /\A(>{1,2})\s*(.+?(?:\.(\w+))?)\s*\Z/ ) {	# redirect output
-	    $render = $render{$3} if $3;
+	if( /\A(>{1,2})\s*(.+?(\.\w+)?)(?:\((.*)\))?\s*\Z/ ) {	# redirect output
+	    set_render $3, $4 ? split ',', $4 : () if $3;
 	    open $fh, "$1:utf8", (glob $2)[0];
 	    select $fh;
 	    goto NEXT;
@@ -932,8 +1033,8 @@ sub shell() {
 	goto NEXT if $skip;
 
       RUN:
-	run $_, $filter if $dbh;
-	undef $render;
+	run $_, $filter, %opt if $dbh;
+	($render, %opt) = ();
 	if( $fh ) {
 	    close;
 	    select STDOUT;
